@@ -32,6 +32,8 @@ public:
           /** destructor */
    ~OptionTraining();
 
+protected:
+   virtual void keyPressEvent(QKeyEvent *);
 };
 
 #endif
